@@ -118,7 +118,11 @@ fn main() {
         Some("QueryUsers") => {
             let result = rt.block_on(client.query_users(
                   Some("username_example".to_string()),
-                  Some("phone_example".to_string())
+                  Some("phone_example".to_string()),
+                  Some("email_example".to_string()),
+                  Some(true),
+                  Some(56),
+                  Some(56)
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
