@@ -926,6 +926,10 @@ impl<S, C> Api<C> for Client<S, C> where
         &self,
         param_username: Option<String>,
         param_phone: Option<String>,
+        param_email: Option<String>,
+        param_enabled: Option<bool>,
+        param_offset: Option<i32>,
+        param_count: Option<i32>,
         context: &C) -> Result<QueryUsersResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
@@ -945,6 +949,22 @@ impl<S, C> Api<C> for Client<S, C> where
                 query_string.append_pair("phone",
                     &param_phone.to_string());
             }
+            if let Some(param_email) = param_email {
+                query_string.append_pair("email",
+                    &param_email.to_string());
+            }
+            if let Some(param_enabled) = param_enabled {
+                query_string.append_pair("enabled",
+                    &param_enabled.to_string());
+            }
+            if let Some(param_offset) = param_offset {
+                query_string.append_pair("offset",
+                    &param_offset.to_string());
+            }
+            if let Some(param_count) = param_count {
+                query_string.append_pair("count",
+                    &param_count.to_string());
+            }
             query_string.finish()
         };
         if !query_string.is_empty() {
@@ -999,7 +1019,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::User>(body)?;
+                let body = serde_json::from_str::<models::UserCollection>(body)?;
                 Ok(QueryUsersResponse::SuccessfulOperation
                     (body)
                 )
