@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.0.4";
+pub const API_VERSION: &'static str = "0.0.5";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -75,7 +75,7 @@ pub enum QueryUserByIdResponse {
 pub enum QueryUsersResponse {
     /// successful operation
     SuccessfulOperation
-    (models::User)
+    (models::UserCollection)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -126,6 +126,10 @@ pub trait Api<C: Send + Sync> {
         &self,
         username: Option<String>,
         phone: Option<String>,
+        email: Option<String>,
+        enabled: Option<bool>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<QueryUsersResponse, ApiError>;
 
 }
@@ -173,6 +177,10 @@ pub trait ApiNoContext<C: Send + Sync> {
         &self,
         username: Option<String>,
         phone: Option<String>,
+        email: Option<String>,
+        enabled: Option<bool>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<QueryUsersResponse, ApiError>;
 
 }
@@ -255,10 +263,14 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         &self,
         username: Option<String>,
         phone: Option<String>,
+        email: Option<String>,
+        enabled: Option<bool>,
+        offset: Option<i32>,
+        count: Option<i32>,
         ) -> Result<QueryUsersResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().query_users(username, phone, &context).await
+        self.api().query_users(username, phone, email, enabled, offset, count, &context).await
     }
 
 }
