@@ -661,10 +661,82 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     },
                     None => None,
                 };
+                let param_email = query_params.iter().filter(|e| e.0 == "email").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_email = match param_email {
+                    Some(param_email) => {
+                        let param_email =
+                            <String as std::str::FromStr>::from_str
+                                (&param_email);
+                        match param_email {
+                            Ok(param_email) => Some(param_email),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter email - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter email")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_enabled = query_params.iter().filter(|e| e.0 == "enabled").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_enabled = match param_enabled {
+                    Some(param_enabled) => {
+                        let param_enabled =
+                            <bool as std::str::FromStr>::from_str
+                                (&param_enabled);
+                        match param_enabled {
+                            Ok(param_enabled) => Some(param_enabled),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter enabled - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter enabled")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_offset = query_params.iter().filter(|e| e.0 == "offset").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_offset = match param_offset {
+                    Some(param_offset) => {
+                        let param_offset =
+                            <i32 as std::str::FromStr>::from_str
+                                (&param_offset);
+                        match param_offset {
+                            Ok(param_offset) => Some(param_offset),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter offset - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter offset")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_count = query_params.iter().filter(|e| e.0 == "count").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_count = match param_count {
+                    Some(param_count) => {
+                        let param_count =
+                            <i32 as std::str::FromStr>::from_str
+                                (&param_count);
+                        match param_count {
+                            Ok(param_count) => Some(param_count),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter count - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter count")),
+                        }
+                    },
+                    None => None,
+                };
 
                                 let result = api_impl.query_users(
                                             param_username,
                                             param_phone,
+                                            param_email,
+                                            param_enabled,
+                                            param_offset,
+                                            param_count,
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
